@@ -33,7 +33,9 @@ GIT_REPOS = ['git://git.linaro.org/people/davelong/lt_ti_lava.git']
 
 INSTALLSTEPS = ['cd lt_ti_lava && make -C utils']
 RUNSTEPS = ['cd lt_ti_lava && make $(OPTIONS) check']
-DEPS = ['git-core', 'linux-libc-dev', 'build-essential', 'wget']
+DEPS = ['git-core', 'linux-libc-dev', 'build-essential', 'wget',
+        'automake', 'libtool', 'libfftw3-dev', 'alsa-utils',
+        'pulseaudio-utils']
 
 # test case id is before ":" and the result is after
 # Each test case is separated with a test description beginning with "#"
