@@ -1,4 +1,4 @@
-#, Copyright (c) 2010, 2011 Linaro
+# Copyright (c) 2010-2012 Linaro
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,33 +24,25 @@ on the kernel.
 
 import re
 
-
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
+VERSION = "20120614"
+INSTALLSTEPS = ['tar --strip-components=1 -jxf ltp-full-%s.bz2' % VERSION,
+                'mkdir build',
+                './configure --prefix=$(readlink -f build)',
+                'make all',
+                'make SKIP_IDCHECK=1 install']
+DEPS = ['bzip2', 'flex', 'bison', 'build-essential']
+URL = ("http://downloads.sourceforge.net/project/ltp/LTP Source/"
+       "ltp-%s/ltp-full-%s.bz2") % (VERSION, VERSION)
+MD5 = "1078160b1f962a22f1598edad17293c5"
 
-VERSION = "20100831"
-URL = ('http://downloads.sourceforge.net/project/ltp/'
-       'LTP Source/ltp-%s/ltp-full-%s.bz2') % (VERSION, VERSION)
-MD5 = "6982c72429a62f3917c13b2d529ad1ce"
-DEPS = ['bzip2', 'flex', 'bison', 'make', 'build-essential']
-
-SCRIPT = """
-tar -xjf ltp-full-20100831.bz2
-mkdir build
-cd ltp-full-20100831
-./configure --prefix=$(readlink -f ../build)
-make all
-SKIP_IDCHECK=1 make install
-"""
+RUNSTEPS = ['cd build && sudo ./runltp $(OPTIONS)']
 DEFAULT_OPTIONS = "-f syscalls -p -q"
 
-INSTALLSTEPS = ["echo '%s' > installltp.sh" % SCRIPT,
-                'chmod +x installltp.sh',
-                './installltp.sh']
-RUNSTEPS = ['cd build && sudo ./runltp $(OPTIONS)']
 PATTERN = (
     "^(?P<test_case_id>\S+)"
     "    (?P<subid>\d+)"
@@ -64,7 +56,6 @@ FIXUPS = {
     "TPASS": "pass",
     "TWARN": "unknown"}
 
-
 class LTPParser(TestParser):
 
     def parse(self, artifacts):
@@ -84,7 +75,6 @@ class LTPParser(TestParser):
                     self.results['test_results'].append(
                         self.analyze_test_result(results))
 
-
 installer = TestInstaller(INSTALLSTEPS, deps=DEPS, url=URL, md5=MD5)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parser = LTPParser(PATTERN, fixupdict=FIXUPS)
