@@ -16,7 +16,7 @@
 """
 xrestop - test for X11 server resource usage monitor
 
-**URL:** None
+**URL:** http://code.launchpad.net/~linaro-foundations/lava-test/xrestopscript
 
 **Default options:** None
 """
@@ -26,12 +26,12 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
-INSTALLSTEPS = ['bzr branch lp:~linaro-foundations/lava-test/xrestopscript']
+BZR_REPOS = ['lp:~linaro-foundations/lava-test/xrestopscript']
 RUNSTEPS = ["./xrestopscript/xrestop.sh $(OPTIONS)"]
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+)"
 DEFAULT_OPTIONS = ""
 
-installer = TestInstaller(INSTALLSTEPS, deps=["xrestop"])
+installer = TestInstaller(deps=["xrestop"], bzr_repos=BZR_REPOS)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parser = TestParser(PATTERN, appendall={'units': 'KB', 'result': 'pass'})
 
